@@ -1,10 +1,10 @@
-/*	$Id: gshhs.h,v 1.18 2008/05/02 00:44:42 guru Exp $
+/*	$Id: gshhs.h,v 1.20 2009/01/09 04:02:35 guru Exp $
  *
  * Include file defining structures used in gshhs.c
  *
  * Paul Wessel, SOEST
  *
- *	Copyright (c) 1996-2008 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1996-2009 by P. Wessel and W. H. F. Smith
  *	See COPYING file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -27,6 +27,7 @@
  *	28-AUG-2007.  PW: Version 1.6.  no format change
  *			  For use with version 1.6 of GSHHS which now has WDBII
  *			  borders and rivers.
+ *	03-JUL-2008.  PW: Version 1.11. New -I<id> option to pull out a single pol
  */
 
 #ifndef _GSHHS
@@ -50,9 +51,9 @@
 #endif
 
 #define GSHHS_DATA_VERSION	6	/* For v1.5 data set */
-#define GSHHS_PROG_VERSION	"1.9"
+#define GSHHS_PROG_VERSION	"1.11"
 
-#define GSHHS_SCL	1.0e-6	/* COnvert micro-degrees to degrees */
+#define GSHHS_SCL	1.0e-6	/* Convert micro-degrees to degrees */
 
 /* For byte swapping on little-endian systems (GSHHS is defined to be bigendian) */
 
