@@ -1,5 +1,5 @@
-/*	$Id: utilmeca.h,v 1.3 2007/02/02 16:23:20 pwessel Exp $
- *    Copyright (c) 1996-2007 by G. Patau
+/*	$Id: utilmeca.h,v 1.9 2009/02/07 00:29:12 jluis Exp $
+ *    Copyright (c) 1996-2009 by G. Patau
  *    Distributed under the GNU Public Licence
  *    See README file for copying and redistribution conditions.
  */
@@ -15,5 +15,5 @@ void define_second_plane(struct nodal_plane NP,struct nodal_plane *NP2);
 double ps_tensor(double x0,double y0,double size,struct AXIS T,struct AXIS N,struct AXIS P,int c_rgb[3],int e_rgb[3], int outline, int plot_zerotrace);
 void axe2dc(struct AXIS T,struct AXIS P,struct nodal_plane *NP1,struct nodal_plane *NP2);
 void ps_pt_axis(double x0,double y0,st_me meca,double size,double *pp,double *dp,double *pt,double *dt,double *xp,double *yp,double *xt,double *yt);
-void momten2axe(struct M_TENSOR mt,struct AXIS *T,struct AXIS *N,struct AXIS *P);
+void GMT_momten2axe(struct M_TENSOR mt,struct AXIS *T,struct AXIS *N,struct AXIS *P);
 void axis2xy(double x0,double y0,double size,double pp,double dp,double pt,double dt,double *xp,double *yp,double *xt,double *yt);
