@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: mgd77manage.c,v 1.103 2008/04/26 00:38:50 guru Exp $
+ *	$Id: mgd77manage.c,v 1.111 2009/01/21 02:01:50 guru Exp $
  *
- *    Copyright (c) 2005-2008 by P. Wessel
+ *    Copyright (c) 2005-2009 by P. Wessel
  * mgd77manage is used to (1) remove data columns from mgd77+ files
  * or (2) add a new data column to mgd77+ files.  Data can be added
  * from data tables, created from reference field formulas, or by
@@ -189,7 +189,7 @@ int main (int argc, char **argv)
 					}
 					break;
 
-				case 'C':	/* Distance calcuation method */
+				case 'C':	/* Distance calculation method */
 					if (argv[i][2] == 'f') dist_flag = 1;
 					if (argv[i][2] == 'g') dist_flag = 2;
 					if (argv[i][2] == 'e') dist_flag = 3;
@@ -263,17 +263,17 @@ int main (int argc, char **argv)
 		fprintf (stderr, "\t-A Append a new data column to the given files.  The code letters are:\n");
 		fprintf (stderr, "\t   +: Optional.  Will overwrite an existing column with same name with new data.\n");
 		fprintf (stderr, "\t   [Default will refuse if an existing column has the same abbreviation as the new data].\n");
-		fprintf (stderr, "\t   a: Give filename with a new column to add.  We expect a single-coloumn file\n");
+		fprintf (stderr, "\t   a: Give filename with a new column to add.  We expect a single-column file\n");
 		fprintf (stderr, "\t      with the same number of records as the MGD77 file.  Only one cruise can be set.\n");
 		fprintf (stderr, "\t      If filename is - we read from stdin.\n");
 		fprintf (stderr, "\t   c: Create a new column to be calculated from existing columns.  Add code:\n");
 		fprintf (stderr, "\t        m = IGRF total field, c = Carter correction, g = IGF (\"normal gravity\")\n");
-		fprintf (stderr, "\t        r = recoputed magnetic anomaly rmag = mtfx - IGRF total field\n");
+		fprintf (stderr, "\t        r = recomputed magnetic anomaly rmag = mtfx - IGRF total field\n");
 		fprintf (stderr, "\t        Append x for which mtfx field to use (1 or 2) [1]\n");
 		fprintf (stderr, "\t        For g, optionally append 1-4 to select the gravity formula to use:\n");
 		fprintf (stderr, "\t        1 = Heiskanen 1924, 2 = International 1930, 3 = IGF1967, 4 = IGF1980.\n");
 		fprintf (stderr, "\t        [Default uses formula specified in the MGD77 header, or 4 if not valid]\n");
-		fprintf (stderr, "\t   d: Give filename with (dist [see -N], data) for a new column.  We expect a two-coloumn file\n");
+		fprintf (stderr, "\t   d: Give filename with (dist [see -N], data) for a new column.  We expect a two-column file\n");
 		fprintf (stderr, "\t      with distances (in km) in first column and data values in 2nd.  Only one cruise can be set.\n");
 		fprintf (stderr, "\t      If filename is - we read from stdin.  Only records with mathcing distance will have data assigned.\n");
 		fprintf (stderr, "\t   D: Same as d but we interpolate between the dist,data pairs to fill in all data records.\n");
@@ -297,10 +297,10 @@ int main (int argc, char **argv)
                 fprintf (stderr, "\t        2 = img file w/ constraints coded, gets data only at constrained points, NaN elsewhere.\n");
                 fprintf (stderr, "\t        3 = img file w/ constraints coded, gets 1 at constraints, 0 elsewhere.\n");
                 fprintf (stderr, "\t        For mode 2|3 you may want to consider the -Q<value> setting.\n");
-		fprintf (stderr, "\t   n: Give filename with (rec_no, data) for a new column.  We expect a two-coloumn file\n");
+		fprintf (stderr, "\t   n: Give filename with (rec_no, data) for a new column.  We expect a two-column file\n");
 		fprintf (stderr, "\t      with record numbers (0 means 1st row) in first column and data values in 2nd.  Only one cruise can be set.\n");
 		fprintf (stderr, "\t      If filename is - we read from stdin.  Only records with matching record numbers will have data assigned.\n");
-		fprintf (stderr, "\t   t: Give filename with (abstime, data) for a new column.  We expect a two-coloumn file\n");
+		fprintf (stderr, "\t   t: Give filename with (abstime, data) for a new column.  We expect a two-column file\n");
 		fprintf (stderr, "\t      with dateTclock strings in first column and data values in 2nd.  Only one cruise can be set.\n");
 		fprintf (stderr, "\t      If filename is - we read from stdin.  Only records with matching times will have data assigned.\n");
 		fprintf (stderr, "\t   T: Same as t but we interpolate between the time, data pairs to fill in all data records.\n");
@@ -547,7 +547,7 @@ int main (int argc, char **argv)
 		if (strings && !two_cols) {	/* Must read strings directly from file since GMT_input would barf */
 			ok_to_read = FALSE;
 			tmp_string = (char **) GMT_memory (VNULL, n_alloc, sizeof (char *), GMT_program);
-			while (fgets (word, BUFSIZ, fp)) {
+			while (GMT_fgets (word, BUFSIZ, fp)) {
 				if (word[0] == '#') continue;
 				width = strlen (word);
 				tmp_string[n] = (char *) GMT_memory (VNULL, (size_t)(width+1), sizeof (char), GMT_program);
@@ -611,7 +611,7 @@ int main (int argc, char **argv)
 
 	MGD77_Ignore_Format (MGD77_FORMAT_ANY);	/* Reset to all formats OK, then ... */
 	MGD77_Ignore_Format (MGD77_FORMAT_M77);	/* disallow ASCII MGD77 files */
-	MGD77_Ignore_Format (MGD77_FORMAT_TBL);	/* and ASCI tables */
+	MGD77_Ignore_Format (MGD77_FORMAT_TBL);	/* and ASCII tables */
 	
 	In.format = MGD77_FORMAT_CDF;	/* Only file type allowed as input */
 	
@@ -940,8 +940,8 @@ int main (int argc, char **argv)
 			int var_id, item;
 			char ID[16], date[16], field[GMT_TEXT_LEN], efile[BUFSIZ], E77[256], timestamp[GMT_TEXT_LEN], answer[BUFSIZ], code[BUFSIZ], YorN, kind;
 			GMT_LONG n_recs, rec, number;
-			int type, it, id, key, n_E77_flags, from, to, day, month, year;
-			int n_E77_headers, n_E77_scales, n_E77_offsets, n_unprocessed, e_error = 0;
+			int type, it, id, key, n_E77_flags, from, to, day, month, year, adjust;
+			int n_E77_headers, n_E77_scales, n_E77_offsets, n_E77_recalcs, n_unprocessed, e_error = 0;
 			unsigned int *flags, pattern;
 			size_t length;
 			BOOLEAN has_time, old_flags;
@@ -969,7 +969,7 @@ int main (int argc, char **argv)
 			 */
 			 
 			P = D->H.mgd77;
-			if (!fgets (line, BUFSIZ, fp_e)) {
+			if (!GMT_fgets (line, BUFSIZ, fp_e)) {
 				fprintf(stderr, "%s: ERROR: Could not read record #1 from %s.e77 - aborting\n", GMT_program, list[argno]);
 				e_error++;
 			}
@@ -995,7 +995,7 @@ int main (int argc, char **argv)
 				e_error++;
 			}
 			verified = FALSE;
-			while (fgets (line, BUFSIZ, fp_e) && strncmp (line, "# Errata: Header", (size_t)14)) {	/* Read until we get to Header record section */
+			while (GMT_fgets (line, BUFSIZ, fp_e) && strncmp (line, "# Errata: Header", (size_t)14)) {	/* Read until we get to Header record section */
 				if (line[0] == '#') continue;	/* Skip comments */
 				GMT_chop (line);		/* Rid the world of CR/LF */
 				if (!strncmp (line, "Y Errata table verification status", (size_t)34)) verified = TRUE;
@@ -1016,7 +1016,7 @@ int main (int argc, char **argv)
 			/* Quickly scan through file to make sure there are no unprocessed recommendations or bad records before making changes */
 			
 			e_error = n_unprocessed = 0;
-			while (fgets (line, BUFSIZ, fp_e)) {
+			while (GMT_fgets (line, BUFSIZ, fp_e)) {
 				if (line[0] == '#' || line[0] == '\n') continue;	/* Comments or blank lines are OK */
 				if (line[1] == '-') {		/* Header record */
 					if (!(line[0] == 'Y' || line[0] == 'N')) {		/* Unprocessed recommendation? */
@@ -1047,16 +1047,16 @@ int main (int argc, char **argv)
 			
 			/* OK, here we believe the E77 file contains the correct information for this cruise. Rewind and start from top */
 			
-			rewind (fp_e);
-			while (fgets (line, BUFSIZ, fp_e) && strncmp (line, "# Errata: Header", (size_t)14));	/* Read until we get to Header record section */
+			GMT_rewind (fp_e);
+			while (GMT_fgets (line, BUFSIZ, fp_e) && strncmp (line, "# Errata: Header", (size_t)14));	/* Read until we get to Header record section */
 			
 			flags = (unsigned int *)GMT_memory (VNULL, (size_t)D->H.n_records, sizeof (unsigned int), GMT_program);
-			n_E77_flags = n_E77_headers = n_E77_scales = n_E77_offsets = 0;
+			n_E77_flags = n_E77_headers = n_E77_scales = n_E77_offsets = n_E77_recalcs = 0;
 
 			MGD77_nc_status (nc_open (In.path, NC_WRITE, &In.nc_id));	/* Open the file */
 			MGD77_nc_status (nc_redef (In.nc_id));				/* Enter define mode */
 			old_flags = MGD77_Remove_E77 (&In);				/* Remove any previously revised header parameters */
-			while (fgets (line, BUFSIZ, fp_e) && strncmp (line, "# Errata: Data", (size_t)14)) {	/* Read until we get to data record section */
+			while (GMT_fgets (line, BUFSIZ, fp_e) && strncmp (line, "# Errata: Data", (size_t)14)) {	/* Read until we get to data record section */
 				if (line[0] == '#' || line[0] == '\n') continue;	/* Skip comments */
 				GMT_chop (line);					/* Rid the world of CR/LF */
 				/* Example of expected line:  
@@ -1123,6 +1123,36 @@ int main (int argc, char **argv)
 						k = MGD77_Info_from_Abbrev (field, &(D->H), &set, &item);
 						value = atof (answer);
 						switch (number) {
+							case E77_HDR_PDR:	/* Must deal with undetected Precision Depth Recorder wrap-arounds - this also force recalc of depth when data is read*/
+								MGD77_nc_status (nc_put_att_double (In.nc_id, NC_GLOBAL, "PDR_wrap", NC_DOUBLE, (size_t)1, &value));
+								adjust = MGD77_COL_ADJ_TWT;
+								MGD77_nc_status (nc_put_att_int (In.nc_id, D->H.info[set].col[id].var_id, "adjust", NC_INT, (size_t)1, &adjust));
+								n_E77_recalcs++;
+								if ((id = MGD77_Get_Column ("depth", &In)) == MGD77_NOT_SET) {
+									fprintf (stderr, "%s: Warning: Correction implied for %s which is not in this cruise?\n", GMT_program, field);
+									break;
+								}
+								/* no break - we want to fall through and also set depth adjustment */
+							case E77_HDR_CARTER:	/* Recalculate Carter depth from twt */
+								adjust = MGD77_COL_ADJ_DEPTH;
+								MGD77_nc_status (nc_put_att_int (In.nc_id, D->H.info[set].col[id].var_id, "adjust", NC_INT, (size_t)1, &adjust));
+								n_E77_recalcs++;
+								break;
+							case E77_HDR_ANOM_MAG:	/* Recalculate anomaly mag as mtf1 - igrf */
+								adjust = MGD77_COL_ADJ_MAG;
+								MGD77_nc_status (nc_put_att_int (In.nc_id, D->H.info[set].col[id].var_id, "adjust", NC_INT, (size_t)1, &adjust));
+								n_E77_recalcs++;
+								break;
+							case E77_HDR_ANOM_FAA:	/* Recalculate anomaly faa as gobs - igf */
+								adjust = MGD77_COL_ADJ_FAA;
+								MGD77_nc_status (nc_put_att_int (In.nc_id, D->H.info[set].col[id].var_id, "adjust", NC_INT, (size_t)1, &adjust));
+								n_E77_recalcs++;
+								break;
+							case E77_HDR_ANOM_FAA_EOT:	/* Recalculate anomaly faa as gobs - igf + eot */
+								adjust = MGD77_COL_ADJ_FAA_EOT;
+								MGD77_nc_status (nc_put_att_int (In.nc_id, D->H.info[set].col[id].var_id, "adjust", NC_INT, (size_t)1, &adjust));
+								n_E77_recalcs++;
+								break;
 							case E77_HDR_SCALE:	/* Correction scale factor */
 								if (D->H.info[set].col[id].corr_factor == 1.0) {	/* Must add a new attribute to the file */
 									D->H.info[set].col[id].corr_factor = value;
@@ -1138,13 +1168,14 @@ int main (int argc, char **argv)
 								n_E77_offsets++;
 								break;
 							case E77_HDR_GRID_OFFSET:	/* Range of bad values - set flags to BAD  */
+							case E77_HDR_FLAGRANGE:		/* Range of bad values - set flags to BAD  */
 								sscanf (answer, "%d-%d", &from, &to);
 								if (from < 1 || from > D->H.n_records || to < 1 || to > D->H.n_records || to < from) {
 									fprintf (stderr, "%s: Error: Record range %s is invalid.  Correction skipped\n", GMT_program, answer);
 									break;
 								}
 								pattern = set_bit (id);
- 								for (rec = from-1; rec < to; rec++, n_E77_flags++) flags[rec] |= pattern;	/* -1 to get C indeces */
+ 								for (rec = from-1; rec < to; rec++, n_E77_flags++) flags[rec] |= pattern;	/* -1 to get C indices */
 								break;
 							default:
 								break;
@@ -1158,7 +1189,7 @@ int main (int argc, char **argv)
 				has_time = FALSE;
 			else
 				tvar = (double *)D->values[it];
-			while (fgets (line, BUFSIZ, fp_e)) {	/* Read until EOF */
+			while (GMT_fgets (line, BUFSIZ, fp_e)) {	/* Read until EOF */
 				sscanf (line, "%c %s %s %ld %s", &YorN, ID, timestamp, &rec, code);
 				if (strcmp (In.NGDC_id, ID)) {
 					fprintf(stderr, "%s: ERROR: E77 Conflict %s : ID = %s versus %s in data records - skipped\n", GMT_program, efile, ID, In.NGDC_id);
@@ -1251,7 +1282,7 @@ int main (int argc, char **argv)
 			/* Update E77 history */
 
 			(void) time (&now);
-			sprintf (E77, "%s [%s] E77 corrections applied to header: %d scale: %d offset: %d flags: %d", ctime(&now), In.user, n_E77_headers, n_E77_scales, n_E77_offsets, n_E77_flags);
+			sprintf (E77, "%s [%s] E77 corrections applied to header: %d scale: %d offset: %d recalc: %d flags: %d", ctime(&now), In.user, n_E77_headers, n_E77_scales, n_E77_offsets, n_E77_recalcs, n_E77_flags);
 			for (i = 0; E77[i]; i++) if (E77[i] == '\n') E77[i] = ' ';	/* Remove the \n returned by ctime() */
 			k = strlen (E77);
 			D->H.E77 = (char *)GMT_memory ((void *)D->H.E77, (size_t)(k+1), sizeof (char), GMT_program);
