@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: pssegyz.c,v 1.31 2008/03/24 08:58:33 guru Exp $
+ *	$Id: pssegyz.c,v 1.34 2009/01/09 04:02:35 guru Exp $
  *
- *    Copyright (c) 1999-2008 by T. Henstock
+ *    Copyright (c) 1999-2009 by T. Henstock
  *    See README file for copying and redistribution conditions.
  *--------------------------------------------------------------------*/
 /* pssegyz program to plot segy files in 3d in postscript with variable trace spacing option
@@ -109,7 +109,7 @@ int main (int argc, char **argv)
 					error += GMT_parse_common_options (argv[i], &w, &e, &s, &n);
 					break;
                                 case 'E':
-					sscanf (&argv[i][2], "%lf/%lf", &z_project.view_azimuth, &z_project.view_elevation);
+					error += GMT_get_proj3D (&argv[i][2], &z_project.view_azimuth, &z_project.view_elevation);
 					break;
 				/* parameters for wiggle mode */
 				case 'F':
@@ -233,7 +233,7 @@ int main (int argc, char **argv)
 					break;
 			}
 			}
-		else if ((fpi = GMT_fopen (argv[i], "rb")) == NULL) {
+		else if ((fpi = fopen (argv[i], "rb")) == NULL) {
 			fprintf (stderr, "%s: Cannot find segy file %s\n",  GMT_program, argv[i]);
 			exit (EXIT_FAILURE);
 		}
@@ -243,7 +243,7 @@ int main (int argc, char **argv)
 	if (argc == 1 || GMT_give_synopsis_and_exit) {
 		fprintf (stderr, "pssegyz %s - Plot a segy file in PostScript\n\n", GMT_VERSION);
 		fprintf (stderr, "usage: pssegyz [<segyfile>] %s %s -D<dev>\n", GMT_Jx_OPT, GMT_Rx_OPT);
-		fprintf (stderr, "	[-E<az/el>] [-C<clip>] [-B<bias>] [-N] [-Z]\n");
+		fprintf (stderr, "	[%s] [-C<clip>] [-B<bias>] [-N] [-Z]\n", GMT_E_OPT);
 		fprintf (stderr, "	[-F<gray>|<r/g/b>] [-I] [-W] [-S<x>/<y>]\n");
 		fprintf (stderr, "	[-X<dx>] [-Y<dz>] [-L<nsamp>] [-M<ntraces>] \n");
 		fprintf (stderr, "	[-U<redvel>] [-A] [-O] [-K] [-P]\n");
