@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: grdrotater.c,v 1.23 2007/09/18 01:32:39 remko Exp $
+ *	$Id: grdrotater.c,v 1.30 2009/01/09 04:02:35 guru Exp $
  *
- *   Copyright (c) 1999-2007 by P. Wessel
+ *   Copyright (c) 1999-2009 by P. Wessel
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -29,8 +29,8 @@
 
 int main (int argc, char **argv)
 {
-	int i, j, k, ij, ii, jj, nx, ny, mx = 0, my, ix, iy;
-	int iii, jjj, ii_o, jj_o;
+	GMT_LONG i, j, k, ij, ii, jj, nx, ny, mx = 0, my, nm, ix, iy;
+	GMT_LONG iii, jjj, ii_o, jj_o;
 
 	BOOLEAN error = FALSE, interpolant = BCR_BICUBIC, user_polygon_given = FALSE;
 	BOOLEAN inside, node = FALSE, outline = TRUE, skip_grid = FALSE;
@@ -231,8 +231,9 @@ int main (int argc, char **argv)
 		ny = irint ( (data_north - data_south) / g_head.y_inc) + !g_head.node_offset;
 		mx = nx + 4;	my = ny + 4;
 		GMT_pad[0] = GMT_pad[1] = GMT_pad[2] = GMT_pad[3] = 2;
+		nm = GMT_get_nm (mx, my);
 
-		original_grid = (float *) GMT_memory (VNULL, (size_t)(mx * my), sizeof (float), GMT_program);
+		original_grid = (float *) GMT_memory (VNULL, (size_t)nm, sizeof (float), GMT_program);
 		GMT_err_fail (GMT_read_grd (grdfile, &g_head, original_grid, data_west, data_east, data_south, data_north, GMT_pad, FALSE), grdfile);
 
 		GMT_boundcond_init (&edgeinfo);
@@ -255,7 +256,7 @@ int main (int argc, char **argv)
 	else				/* Make a single grid-outline polygon */
 		get_grid_path (&g_head, &pol);
 
-	make_rot_matrix (x_rot, y_rot, w_rot, R);	/* Make rotation matrix from rotation parameters */
+	spotter_make_rot_matrix (x_rot, y_rot, w_rot, R);	/* Make rotation matrix from rotation parameters */
 	
 	if (gmtdefs.verbose) fprintf (stderr, "%s: Reconstruct polygon outline\n", GMT_program);
 	
@@ -268,7 +269,7 @@ int main (int argc, char **argv)
 		wp360 = wp180 = DBL_MAX;	ep360 = ep180 = -DBL_MAX;	spol = DBL_MAX;	npol = -DBL_MAX;
 		for (j = 0; j < pol->segment[i]->n_rows; j++) {
 			GMT_geo_to_cart (&pol->segment[i]->coord[GMT_Y][j], &pol->segment[i]->coord[GMT_X][j], P_original, TRUE);	/* Convert to a Cartesian x,y,z vector; TRUE since we have degrees */
-			matrix_vect_mult (R, P_original, P_rotated);				/* Rotate the vector */
+			spotter_matrix_vect_mult (R, P_original, P_rotated);				/* Rotate the vector */
 			GMT_cart_to_geo (&pol->segment[i]->coord[GMT_Y][j], &pol->segment[i]->coord[GMT_X][j], P_rotated, TRUE);	/* Recover lon lat representation; TRUE to get degrees */
 			if (pol->segment[i]->coord[GMT_Y][j] < south) south = pol->segment[i]->coord[GMT_Y][j];
 			if (pol->segment[i]->coord[GMT_Y][j] > north) north = pol->segment[i]->coord[GMT_Y][j];
@@ -314,7 +315,7 @@ int main (int argc, char **argv)
 		exit (EXIT_SUCCESS);
 	}
 	
-	/* Then, find min/max of reconstucted outline */
+	/* Then, find min/max of reconstructed outline */
 	
 	if (fabs (e360 - w360) < 180.0) {
 		west = w360;
@@ -351,7 +352,7 @@ int main (int argc, char **argv)
 	
 	if (gmtdefs.verbose) fprintf (stderr, "%s: Interpolate reconstructed grid\n", GMT_program);
 
-	make_rot_matrix (x_rot, y_rot, -w_rot, R);	/* Make inverse rotation using negative angle */
+	spotter_make_rot_matrix (x_rot, y_rot, -w_rot, R);	/* Make inverse rotation using negative angle */
 	for (j = ij = 0; j < r_head.ny; j++) {
 		for (i = 0; i < r_head.nx; i++, ij++) {
 			rotated_grid[ij] = GMT_f_NaN;
@@ -367,7 +368,7 @@ int main (int argc, char **argv)
 			
 			xx = grd_x[i];	yy = grd_y[j];
 			GMT_geo_to_cart (&yy, &xx, P_rotated, TRUE);	/* Convert degree lon,lat to a Cartesian x,y,z vector */
-			matrix_vect_mult (R, P_rotated, P_original);	/* Rotate the vector */
+			spotter_matrix_vect_mult (R, P_rotated, P_original);	/* Rotate the vector */
 			GMT_cart_to_geo (&yy, &xx, P_original, TRUE);	/* Recover degree lon lat representation */
 			xx -= 360.0;
 			while (xx < g_head.x_min) xx += 360.0;	/* Make sure we deal with 360 issues */
@@ -398,7 +399,7 @@ int main (int argc, char **argv)
 					if (!GMT_is_fnan (rotated_grid[ij])) continue;	/* Already done this */
 					xx = grd_x[iii];	yy = grd_y[jjj];
 					GMT_geo_to_cart (&yy, &xx, P_rotated, TRUE);	/* Convert degree lon,lat to a Cartesian x,y,z vector */
-					matrix_vect_mult (R, P_rotated, P_original);	/* Rotate the vector */
+					spotter_matrix_vect_mult (R, P_rotated, P_original);	/* Rotate the vector */
 					GMT_cart_to_geo (&xx, &yy, P_original, TRUE);	/* Recover degree lon lat representation */
 					ii_o = GMT_x_to_i (xx, g_head.x_min, g_head.x_inc, g_head.xy_off, g_head.nx);
 					if (ii_o < 0 || ii_o >= g_head.nx) continue;
@@ -440,28 +441,28 @@ void get_grid_path (struct GRD_HEADER *h, struct GMT_TABLE **p)
 	 * Note that the path is the same for pixel or grid-registered grids.
 	 */
 
-	int np = 0, add, i, j;
+	GMT_LONG np = 0, add, i, j;
 	struct GMT_TABLE *pol;
 	
-	pol = (struct GMT_TABLE *)GMT_memory (VNULL, 1, sizeof (struct GMT_TABLE), GMT_program);
-	pol->segment = (struct GMT_LINE_SEGMENT **) GMT_memory (VNULL, 1, sizeof (struct GMT_LINE_SEGMENT *), GMT_program);
-	pol->segment[0] = (struct GMT_LINE_SEGMENT *) GMT_memory (VNULL, 1, sizeof (struct GMT_LINE_SEGMENT), GMT_program);
-	pol->segment[0]->coord = (double **)GMT_memory (VNULL, 2, sizeof (double *), GMT_program);
-	pol->segment[0]->min = (double *)GMT_memory (VNULL, 2, sizeof (double), GMT_program);
-	pol->segment[0]->max = (double *)GMT_memory (VNULL, 2, sizeof (double), GMT_program);
+	pol = (struct GMT_TABLE *)GMT_memory (VNULL, (size_t)1, sizeof (struct GMT_TABLE), GMT_program);
+	pol->segment = (struct GMT_LINE_SEGMENT **) GMT_memory (VNULL, (size_t)1, sizeof (struct GMT_LINE_SEGMENT *), GMT_program);
+	pol->segment[0] = (struct GMT_LINE_SEGMENT *) GMT_memory (VNULL, (size_t)1, sizeof (struct GMT_LINE_SEGMENT), GMT_program);
+	pol->segment[0]->coord = (double **)GMT_memory (VNULL, (size_t)2, sizeof (double *), GMT_program);
+	pol->segment[0]->min = (double *)GMT_memory (VNULL, (size_t)2, sizeof (double), GMT_program);
+	pol->segment[0]->max = (double *)GMT_memory (VNULL,(size_t) 2, sizeof (double), GMT_program);
 		
 	/* Add south border w->e */
 	if (h->y_min == -90.0) {	/* If at the S pole we just add it twice for end longitudes */
 		add = 2;
-		pol->segment[0]->coord[GMT_X] = (double *)GMT_memory (VNULL, add, sizeof (double), GMT_program);
-		pol->segment[0]->coord[GMT_Y] = (double *)GMT_memory (VNULL, add, sizeof (double), GMT_program);
+		pol->segment[0]->coord[GMT_X] = (double *)GMT_memory (VNULL, (size_t)add, sizeof (double), GMT_program);
+		pol->segment[0]->coord[GMT_Y] = (double *)GMT_memory (VNULL, (size_t)add, sizeof (double), GMT_program);
 		pol->segment[0]->coord[GMT_X][0] = h->x_min;	pol->segment[0]->coord[GMT_X][1] = h->x_max;
 		pol->segment[0]->coord[GMT_Y][0] = pol->segment[0]->coord[GMT_Y][1] = h->y_min;
 	}
 	else {				/* Loop along south border from west to east */
 		add = h->nx - !h->node_offset;
-		pol->segment[0]->coord[GMT_X] = (double *)GMT_memory (VNULL, add, sizeof (double), GMT_program);
-		pol->segment[0]->coord[GMT_Y] = (double *)GMT_memory (VNULL, add, sizeof (double), GMT_program);
+		pol->segment[0]->coord[GMT_X] = (double *)GMT_memory (VNULL, (size_t)add, sizeof (double), GMT_program);
+		pol->segment[0]->coord[GMT_Y] = (double *)GMT_memory (VNULL, (size_t)add, sizeof (double), GMT_program);
 		for (i = 0; i < add; i++) {
 			pol->segment[0]->coord[GMT_X][i] = GMT_i_to_x (i, h->x_min, h->x_max, h->x_inc, 0.0, h->nx);
 			pol->segment[0]->coord[GMT_Y][i] = h->y_min;
@@ -470,8 +471,8 @@ void get_grid_path (struct GRD_HEADER *h, struct GMT_TABLE **p)
 	np += add;
 	/* Add east border s->n */
 	add = h->ny - !h->node_offset;
-	pol->segment[0]->coord[GMT_X] = (double *)GMT_memory ((void *)pol->segment[0]->coord[GMT_X], add + np, sizeof (double), GMT_program);
-	pol->segment[0]->coord[GMT_Y] = (double *)GMT_memory ((void *)pol->segment[0]->coord[GMT_Y], add + np, sizeof (double), GMT_program);
+	pol->segment[0]->coord[GMT_X] = (double *)GMT_memory ((void *)pol->segment[0]->coord[GMT_X], (size_t)(add + np), sizeof (double), GMT_program);
+	pol->segment[0]->coord[GMT_Y] = (double *)GMT_memory ((void *)pol->segment[0]->coord[GMT_Y], (size_t)(add + np), sizeof (double), GMT_program);
 	for (j = 0; j < add; j++) {	/* Loop along east border from south to north */
 		pol->segment[0]->coord[GMT_X][np+j] = h->x_max;
 		pol->segment[0]->coord[GMT_Y][np+j] = GMT_j_to_y (h->ny - 1 - j, h->y_min, h->y_max, h->y_inc, 0.0, h->ny);
@@ -480,15 +481,15 @@ void get_grid_path (struct GRD_HEADER *h, struct GMT_TABLE **p)
 	/* Add north border e->w */
 	if (h->y_max == 90.0) {	/* If at the N pole we just add it twice for end longitudes */
 		add = 2;
-		pol->segment[0]->coord[GMT_X] = (double *)GMT_memory ((void *)pol->segment[0]->coord[GMT_X], add + np, sizeof (double), GMT_program);
-		pol->segment[0]->coord[GMT_Y] = (double *)GMT_memory ((void *)pol->segment[0]->coord[GMT_Y], add + np, sizeof (double), GMT_program);
+		pol->segment[0]->coord[GMT_X] = (double *)GMT_memory ((void *)pol->segment[0]->coord[GMT_X], (size_t)(add + np), sizeof (double), GMT_program);
+		pol->segment[0]->coord[GMT_Y] = (double *)GMT_memory ((void *)pol->segment[0]->coord[GMT_Y], (size_t)(add + np), sizeof (double), GMT_program);
 		pol->segment[0]->coord[GMT_X][np] = h->x_max;	pol->segment[0]->coord[GMT_X][np+1] = h->x_min;
 		pol->segment[0]->coord[GMT_Y][np] = pol->segment[0]->coord[GMT_Y][np+1] = h->y_max;
 	}
 	else {			/* Loop along north border from east to west */
 		add = h->nx - !h->node_offset;
-		pol->segment[0]->coord[GMT_X] = (double *)GMT_memory ((void *)pol->segment[0]->coord[GMT_X], add + np, sizeof (double), GMT_program);
-		pol->segment[0]->coord[GMT_Y] = (double *)GMT_memory ((void *)pol->segment[0]->coord[GMT_Y], add + np, sizeof (double), GMT_program);
+		pol->segment[0]->coord[GMT_X] = (double *)GMT_memory ((void *)pol->segment[0]->coord[GMT_X], (size_t)(add + np), sizeof (double), GMT_program);
+		pol->segment[0]->coord[GMT_Y] = (double *)GMT_memory ((void *)pol->segment[0]->coord[GMT_Y], (size_t)(add + np), sizeof (double), GMT_program);
 		for (i = 0; i < add; i++) {
 			pol->segment[0]->coord[GMT_X][np+i] = GMT_i_to_x (h->nx - 1 - i, h->x_min, h->x_max, h->x_inc, 0.0, h->nx);
 			pol->segment[0]->coord[GMT_Y][np+i] = h->y_max;
@@ -497,8 +498,8 @@ void get_grid_path (struct GRD_HEADER *h, struct GMT_TABLE **p)
 	np += add;
 	/* Add west border n->s */
 	add = h->ny - !h->node_offset;
-	pol->segment[0]->coord[GMT_X] = (double *)GMT_memory ((void *)pol->segment[0]->coord[GMT_X], add + np + 1, sizeof (double), GMT_program);
-	pol->segment[0]->coord[GMT_Y] = (double *)GMT_memory ((void *)pol->segment[0]->coord[GMT_Y], add + np + 1, sizeof (double), GMT_program);
+	pol->segment[0]->coord[GMT_X] = (double *)GMT_memory ((void *)pol->segment[0]->coord[GMT_X], (size_t)(add + np + 1), sizeof (double), GMT_program);
+	pol->segment[0]->coord[GMT_Y] = (double *)GMT_memory ((void *)pol->segment[0]->coord[GMT_Y], (size_t)(add + np + 1), sizeof (double), GMT_program);
 	for (j = 0; j < add; j++) {	/* Loop along west border from north to south */
 		pol->segment[0]->coord[GMT_X][np+j] = h->x_min;
 		pol->segment[0]->coord[GMT_Y][np+j] = GMT_j_to_y (j, h->y_min, h->y_max, h->y_inc, 0.0, h->ny);
